@@ -239,18 +239,6 @@ def main_standalone( argc, argv ):
         from Foam.finiteVolume import surfaceScalarField
         amaxSf = surfaceScalarField( word( "amaxSf" ), am.mag().ext_max( ap.mag() ) )
         
-        CoNum, meanCoNum = compressibleCourantNo( mesh, amaxSf, runTime )
-        
-        from Foam.finiteVolume.cfdTools.general.include import readTimeControls
-        adjustTimeStep, maxCo, maxDeltaT = readTimeControls( runTime )
-        
-        from Foam.finiteVolume.cfdTools.general.include import setDeltaT
-        runTime = setDeltaT( runTime, adjustTimeStep, maxCo, maxDeltaT, CoNum )
-        
-        runTime.increment()
-        
-        ext_Info() << "Time = " << runTime.timeName() << nl << nl
-        
         aSf = am * a_pos
 
         if str( fluxScheme ) == "Tadmor":
@@ -266,7 +254,22 @@ def main_standalone( argc, argv ):
         aphiv_pos = phiv_pos - aSf
         
         aphiv_neg = phiv_neg + aSf
+        
+        # Reuse amaxSf for the maximum positive and negative fluxes
+        # estimated by the central scheme
+        amaxSf.ext_assign( aphiv_pos.mag().ext_max(  aphiv_neg.mag() ) )
 
+        CoNum, meanCoNum = compressibleCourantNo( mesh, amaxSf, runTime )
+        
+        from Foam.finiteVolume.cfdTools.general.include import readTimeControls
+        adjustTimeStep, maxCo, maxDeltaT = readTimeControls( runTime )
+        
+        from Foam.finiteVolume.cfdTools.general.include import setDeltaT
+        runTime = setDeltaT( runTime, adjustTimeStep, maxCo, maxDeltaT, CoNum )
+        
+        runTime.increment()
+        
+        ext_Info() << "Time = " << runTime.timeName() << nl << nl
         phi = None
 
         phi = surfaceScalarField( word( "phi" ), aphiv_pos * rho_pos + aphiv_neg * rho_neg )
@@ -344,8 +347,8 @@ def main_standalone( argc, argv ):
 
 #--------------------------------------------------------------------------------------
 import sys, os
-from Foam import FOAM_REF_VERSION
-if FOAM_REF_VERSION( "==", "010600" ):
+from Foam import FOAM_REF_VERSION, FOAM_BRANCH_VERSION
+if FOAM_REF_VERSION( ">=", "010700" ) or FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
    if __name__ == "__main__" :
       argv = sys.argv
       os._exit( main_standalone( len( argv ), argv ) )
@@ -353,9 +356,7 @@ if FOAM_REF_VERSION( "==", "010600" ):
    pass   
 else:
    from Foam.OpenFOAM import ext_Info
-   ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam1.6 \n "
+   ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam1.7.0 or 1.6-ext or higher \n "
 
-
-    
+   
 #--------------------------------------------------------------------------------------
-
